clear all 

%read data pore water
MI=readtable('Leaching_FeCN_UVVIS.xlsx','sheet','MI','range','A1:E14'); 
CA=readtable('Leaching_FeCN_UVVIS.xlsx','sheet','CA','range','A1:E14'); 
CSCA=readtable('Leaching_FeCN_UVVIS.xlsx','sheet','CsCA','range','A1:E14'); 

%% Absolute amount
V_MI=[434.53 436.62 436.62]; %leachant volume
V_CA=[468.39 461.62 461.62];%leachant volume
V_CsCA=[438.88 428.93 440.15];%leachant volume

C_MI=[MI.MI1 MI.MI2 MI.MI3].*21.37.*MI.D.*V_MI/1000; %absolute in mg
C_CA=[CA.CA1 CA.CA2 CA.CA3].*21.37.*CA.D.*V_CA/1000; %absolute in mg
C_CSCA=[CSCA.CSCA1 CSCA.CSCA2 CSCA.CSCA3].*21.37.*CSCA.D.*V_CsCA/1000; %absolute in mg

%%
% Concentration

%C_MI=[MI.MI1 MI.MI2 MI.MI3].*21.37.*MI.D;
%C_CA=[CA.CA1 CA.CA2 CA.CA3].*21.37.*CA.D;
%C_CSCA=[CSCA.CSCA1 CSCA.CSCA2 CSCA.CSCA3].*21.37.*CSCA.D;

%% Cumulative
Cum_MI=cumsum(C_MI,1);
Cum_CA=cumsum(C_CA,1);
Cum_CSCA=cumsum(C_CSCA,1);
%% Initial amount and CFL calculation
CWE_MI=[75.85 81.06 79.54 ]; %absolute amount FeCn in mg left after CWE
CWE_CA=[101.84 92.37 96.65]; %absolute amount in mg left after CWE
CWE_CSCA=[273.93 287.03 282.7]; %absolute amount in mg left after CWE

A0_MI=Cum_MI(end,:)+CWE_MI;
A0_CA=Cum_CA(end,:)+CWE_CA;
A0_CSCA=Cum_CSCA(end,:)+CWE_CSCA;


CFL_MI=Cum_MI./A0_MI;
CFL_CA=Cum_CA./A0_CA;
CFL_CSCA=Cum_CSCA./A0_CSCA;

mu_MI=mean(CFL_MI,2);
mu_CA=mean(CFL_CA,2);
mu_CSCA=mean(CFL_CSCA,2);

%std
sd_MI=std(CFL_MI,0,2)*1; %2 std error--> 95% data
sd_CA=std(CFL_CA,0,2)*1;
sd_CSCA=std(CFL_CSCA,0,2)*1;

%% mean and average concentration/absolute
% 
% mu_MI=mean(Cum_MI,2);
% mu_CA=mean(Cum_CA,2);
% mu_CSCA=mean(Cum_CSCA,2);
% 
% %std
% sd_MI=std(Cum_MI,0,2);
% sd_CA=std(Cum_CA,0,2);
% sd_CSCA=std(Cum_CSCA,0,2);



% %%
% f1=figure;
% errorbar(MI.t,mu_MI,sd_MI, '^-','color',[0 0 1],'MarkerFaceColor',[0 0 1],'LineWidth',1.2);%Reference
% hold on
% errorbar(CA.t,mu_CA,sd_CA, '^-','color',[0 0.8 0],'MarkerFaceColor',[0 0.8 0 ],'LineWidth',1.2);%inhibitor
% errorbar(CSCA.t,mu_CSCA,sd_CSCA, '^-','color',[1 0 0],'MarkerFaceColor',[1 0 0 ]','LineWidth',1.2);%salt
% grid on
% xlabel('t [days]','Interpreter','tex');
% ylabel('Cumulative fraction leached') 
% legend('MI','CA','CsCA','location','southeast','Orientation','vertical','FontSize',14,'box','off');
% %xlim([0 375]);
% %ylim([0 350]);
% %yticks([0:3:15])
% set(gca,'FontSize',16);
% exportgraphics(f1,'CFL.pdf','Resolution',300);
% exportgraphics(f1,'CFL.tiff','Resolution',300);
%% mean and average concentration


mu_MI_raw=mean(C_MI,2);
mu_CA_raw=mean(C_CA,2);
mu_CSCA_raw=mean(C_CSCA,2);

%std
sd_MI_raw=std(C_MI,0,2);
sd_CA_raw=std(C_CA,0,2);
sd_CSCA_raw=std(C_CSCA,0,2);
%% concentration profile
f2=figure;
errorbar(MI.t,mu_MI_raw,sd_MI_raw, '^-','color',[0 0 1],'MarkerFaceColor',[0 0 1],'LineWidth',1.2);%Reference
hold on
errorbar(CA.t,mu_CA_raw,sd_CA_raw, '^-','color',[0 0.8 0],'MarkerFaceColor',[0 0.8 0 ],'LineWidth',1.2);%inhibitor
errorbar(CSCA.t,mu_CSCA_raw,sd_CSCA_raw, '^-','color',[1 0 0],'MarkerFaceColor',[1 0 0 ]','LineWidth',1.2);%salt
grid on
xlabel('t [days]','Interpreter','tex');
ylabel('Concentration [mg/L]')
legend('MI','CA','CsCA','location','southeast','Orientation','vertical','FontSize',14,'box','off');
%xlim([0 375]);
%ylim([0 350]);
%yticks([0:3:15])
set(gca,'FontSize',16);
%exportgraphics(f1,'Capsule_leaching_cum.pdf','Resolution',300);
%exportgraphics(f1,'Capsule_leaching_cum.tiff','Resolution',300);

%% Diffusion Coefficient

%% Non linear regression
[b1,MI_fit,Rsq_MI,MSE_MI,N1]=pescatore(MI.t,mu_MI,[0.1],1.594, 4.933); %pescatore(x,y,b0,R,H) R and H in cm
[b2,CA_fit,Rsq_CA,MSE_CA,N2]=pescatore(CA.t,mu_CA,[0.1],1.616,5.23);
[b3,CSCA_fit,Rsq_CSCA,MSE_CSCA,N4]=pescatore(CSCA.t,mu_CSCA,[0.1],1.627,4.767);
f3=figure

t1=0:0.01:10;

errorbar(MI.t,mu_MI,sd_MI,'b.','LineWidth',1.5,'LineStyle','none','MarkerSize',15)
hold on
plot(t1,MI_fit,'b--','LineWidth',1.6)
errorbar(CA.t,mu_CA,sd_CA,'color','[0 0.8 0]','LineWidth',1.5,'LineStyle','none','Marker','.','MarkerSize',15)
plot(t1,CA_fit,'color','[0 0.8 0]','LineStyle','--','LineWidth',1.2)
errorbar(CSCA.t,mu_CSCA,sd_CSCA,'r.','LineWidth',1.5,'LineStyle','none','MarkerSize',15)
plot(t1,CSCA_fit,'r--','LineWidth',1.2)
hold off
ylim([0,1])
xlim([0,10])
xlabel('Time [days]');
ylabel('Cumulative fraction leached');
grid off
legend('Mortar-F','Mortar-F fit','Mortar-CA-F','Mortar-CA-F fit','Mortar-Cs-CA-F','Mortar-Cs-CA-F fit','location','southeast','Orientation','horizontal','NumColumns',2,'fontsize',12)
%icons = findobj(icons,'Type','line');
%icons = findobj(icons,'Marker','none','-xor');
%set(icons,'MarkerSize',20);
legend box off
set(gca,'FontSize',16);
set(gca,'Units','normalized','OuterPosition',[0 0 1 1]);
% txt1 = sprintf('R^2= %0.2f',Rsq_S);
% txt2 =sprintf('R^2= %0.2f',Rsq_I);
% text(1,0.95,txt1,'FontSize',14)
% text(4,0.45,txt2,'FontSize',14)
% 
txt11 = sprintf('D_{Mortar-F}: %.1e cm^2 s^{-1}, R^2=%.3f',b1/86400, Rsq_MI);
txt22 =sprintf('D_{Mortar-CA-F}: %.1e cm^2 s^{-1}, R^2=%.3f',b2/86400, Rsq_CA );
txt33 =sprintf('D_{Mortar-Cs-CA-F}: %.1e cm^2 s^{-1}, R^2=%.3f',b3/86400,Rsq_CSCA );
text(0.1,0.95,txt11,'FontSize',12)
text(0.1,0.85,txt22,'FontSize',12)
text(0.1,0.75,txt33,'FontSize',12)
% set(gca,'fontsize',18)
% disp(b1/86400);
% disp(b2/86400);


exportgraphics(f3,'Diffusion coefficient_Pescatore_2sigma_R2.tif','Resolution',300)
exportgraphics(f3,'Diffusion coefficient_Pescatore_2sigma_R2.pdf','Resolution',300)

%%
f26=figure

t1=0:0.01:10;

errorbar(MI.t,mu_MI,sd_MI,'b.','LineWidth',1.5,'LineStyle','none','MarkerSize',15)
hold on
plot(t1,MI_fit,'b--','LineWidth',1.6)
%errorbar(CA.t,mu_CA,sd_CA,'color','[0 0.8 0]','LineWidth',1.5,'LineStyle','none','Marker','.','MarkerSize',15)
%plot(t1,CA_fit,'color','[0 0.8 0]','LineStyle','--','LineWidth',1.2)
errorbar(CSCA.t,mu_CSCA,sd_CSCA,'r.','LineWidth',1.5,'LineStyle','none','MarkerSize',15)
plot(t1,CSCA_fit,'r--','LineWidth',1.2)
hold off
ylim([0,1])
xlim([0,10])
xlabel('Time [days]');
ylabel('Cumulative fraction leached');
grid off
%legend('Mortar-F','Mortar-F fit','Mortar-CA-F','Mortar-CA-F fit','Mortar-Cs-CA-F','Mortar-Cs-CA-F fit','location','northwest','Orientation','horizontal','NumColumns',2,'fontsize',12)
%legend('Mortar-F','','Mortar-CA-F','','Mortar-Cs-CA-F','','location','northwest','Orientation','vertical','NumColumns',1,'fontsize',14)
legend('Mortar-F','Mortar-Cs-CA-F','location','southeast','Orientation','vertical','fontsize',12)
%icons = findobj(icons,'Type','line');
%icons = findobj(icons,'Marker','none','-xor');
%set(icons,'MarkerSize',20);
legend box off
set(gca,'FontSize',12);
set(gca,'Units','normalized','OuterPosition',[0 0 1 1]);
% txt1 = sprintf('R^2= %0.2f',Rsq_S);
% txt2 =sprintf('R^2= %0.2f',Rsq_I);
% text(1,0.95,txt1,'FontSize',14)
% text(4,0.45,txt2,'FontSize',14)
% 
%txt11 = sprintf('D_{Mortar-F}: %.1e cm^2 s^{-1}, R^2=%.3f',b1/86400, Rsq_MI);
%txt22 =sprintf('D_{Mortar-CA-F}: %.1e cm^2 s^{-1}, R^2=%.3f',b2/86400, Rsq_CA );
%txt33 =sprintf('D_{Mortar-Cs-CA-F}: %.1e cm^2 s^{-1}, R^2=%.3f',b3/86400,Rsq_CSCA );
%text(0.1,0.95,txt11,'FontSize',12)
%text(0.1,0.85,txt22,'FontSize',12)
%text(0.1,0.75,txt33,'FontSize',12)
% set(gca,'fontsize',18)
% disp(b1/86400);
% disp(b2/86400);


exportgraphics(f26,'BK-lab.tif','Resolution',300)
%exportgraphics(f26,'Graphical abstract.pdf','Resolution',300)

%%

CWE_MI_sd=std(CWE_MI,0);
CWE_CA_sd=std(CWE_CA,0);
CWE_CSCA_sd=std(CWE_CSCA,0);

CWE(1,1)=mean(CWE_MI);
CWE(1,2)=mean(CWE_CA);
CWE(1,3)=mean(CWE_CSCA);


f4=figure
b=bar(CWE)
hold on
errorbar(CWE,[CWE_MI_sd,CWE_CA_sd,CWE_CSCA_sd],'k','linestyle','none');
set(gca,'xticklabel',{'Mortar-F';'Mortar-CA-F';'Mortar-Cs-CA-F'}')
b(1).BarWidth=0.5;
b.FaceColor = 'flat';
b.CData(1,:) = [0 0 1];
b.CData(2,:) = [0 1 0];
b.CData(3,:) = [1 0 0];
ylabel('NaFeCN left [mg]');
set(gca,'FontSize',11);
set(gca,'Units','normalized','OuterPosition',[0 0 1 1]);
exportgraphics(f4,'CWE_NaFeCN left_R2.tif','Resolution',300)
exportgraphics(f4,'CWE_NaFeCN left_R2.pdf','Resolution',300)