clear all 
%Plot data of release of NaFECN measured using UV-VIS in mortar pore
%solution
%read data release of FeCN in pore solution (with initial 4% FeCN in
%capsules)
CA=readtable('porerelease_4%.xlsx','sheet','CA','range','A1:F15'); %calcium alginate
CA_2p=readtable('porerelease_4%.xlsx','sheet','CA_2%','range','A1:F15'); 
Cs250=readtable('porerelease_4%.xlsx','sheet','Cs250','range','A1:F15'); %Cs:CA 0.25
Cs375=readtable('porerelease_4%.xlsx','sheet','Cs375','range','A1:F15'); %Cs:CA 0.375
Cs500=readtable('porerelease_4%.xlsx','sheet','Cs500','range','A1:F15'); %Cs:CA 0.5

%%read data release of FeCN in pore solution (with initial 2% FeCN in
%capsules)
NCA=readtable('Pore water release_2%.xlsx','sheet','CA','range','A1:F15'); %calcium alginate
NCs250=readtable('Pore water release_2%.xlsx','sheet','Cs250','range','A1:F15'); %Cs:CA 0.25
NCs375=readtable('Pore water release_2%.xlsx','sheet','Cs375','range','A1:F15'); %Cs:CA 0.375
NCs500=readtable('Pore water release_2%.xlsx','sheet','Cs500','range','A1:F15');  %Cs:CA 0.5





%%Concentrations
C_CA=CA.Abs.*CA.D*21.37;%  calibration C=21.37*ABS, D=dilution factor
C_CA_2p=CA_2p.Abs.*CA_2p.D*21.37;
C_Cs250=Cs250.Abs.*Cs250.D*21.37;
C_Cs375=Cs375.Abs.*Cs375.D*21.37;
C_Cs500=Cs500.Abs.*Cs500.D*21.37;

C_NCA=NCA.Abs.*NCA.D*21.37;%calibration C=21.37*ABS, D=dilution factor
C_NCs250=NCs250.Abs.*NCs250.D*21.37;
C_NCs375=NCs375.Abs.*NCs375.D*21.37;
C_NCs500=NCs500.Abs.*NCs500.D*21.37;




%%
f1=figure;
plot(CA.Time,C_CA,'ko-','LineWidth',1.3) %4 CA
hold on
plot(NCA.Time,C_NCA,'ko--','LineWidth',1.3) %2% CA

plot(Cs250.Time,C_Cs250,'s-','LineWidth',1.3,'Color',[1 0.8 0.8])
plot(NCs250.Time,C_NCs250,'s-','LineWidth',1.3,'Color',[0.8 0.8 1])

plot(Cs375.Time,C_Cs375,'d-','LineWidth',1.3,'Color',[1 0.5 0.5])
plot(NCs375.Time,C_NCs375,'d-','LineWidth',1.3,'Color',[0.5 0.5 1])

plot(Cs500.Time,C_Cs500,'^-','LineWidth',1.3,'Color',[1 0 0])
plot(Cs500.Time,C_NCs500,'^-','LineWidth',1.3,'Color',[0 0 1])

grid on
xlabel('t [min]','Interpreter','tex');
ylabel('Concentration [mg/L]')
legend('CA 4%','CA 2%', 'Cs/CA 0.25 4%','NCs/CA 0.25 2%','Cs/CA 0.375 4%','NCs/CA 0.375 2%','Cs/CA 0.5 4%','NCs/CA 0.5 2%','location','north outside','Orientation','horizontal','FontSize',10,'box','on','NumColumns',2);
%title('Pore solution 2%');
xlim([0 375]);
%ylim([0 350]);
%yticks([0:3:15])
set(gca,'FontSize',16);
%exportgraphics(f1,'poresolution.pdf');
exportgraphics(f1,'poresolution.png','Resolution',300);
%%
% f2=figure
% plot(NCA.Time,C_NCA,'ko-','LineWidth',1.3)
% hold on
% plot(NCs250.Time,C_NCs250,'rs-','LineWidth',1.3)
% plot(NCs375.Time,C_NCs375,'rd:','LineWidth',1.3)
% plot(NCs500.Time,C_NCs500,'r^--','LineWidth',1.3)
% grid on
% xlabel('t [min]','Interpreter','tex');
% ylabel('Concentration [mg/L]')
% legend('CA','Cs/CA 0.25','Cs/CA 0.375','Cs/CA0.5','location','northeast','Orientation','horizontal','FontSize',14,'box','off','NumColumns',2);
% title('Pore solution + 5% NaCl');
% xlim([0 375]);
% ylim([0 350]);
% %yticks([0:3:15])
% set(gca,'FontSize',16);
% exportgraphics(f2,'Pore solution + NaCl.pdf');
% exportgraphics(f2,'Pore solution + NaCl.png');
%% Concentrations in mg/g

f3=figure
plot(CA.Time,C_CA.*(CA.Vol_ml/1000)./(CA.mass_mg/1000),'ko-','LineWidth',1.3)
hold on
plot(CA_2p.Time,C_CA_2p.*(CA_2p.Vol_ml/1000)./(CA_2p.mass_mg/1000),'bo-','LineWidth',1.3)

plot(Cs250.Time,C_Cs250.*(Cs250.Vol_ml/1000)./(Cs250.mass_mg/1000),'rs-','LineWidth',1.3)
plot(Cs375.Time,C_Cs375.*(Cs375.Vol_ml/1000)./(Cs375.mass_mg/1000),'rd:','LineWidth',1.3)
plot(Cs500.Time,C_Cs500.*(Cs500.Vol_ml/1000)./(Cs500.mass_mg/1000),'r^--','LineWidth',1.3)
grid on
xlabel('t [min]','Interpreter','tex');
ylabel('FeCN/capsule [mg/g]')
legend('CA-4% FeCN','CA-2% FeCN','Cs/CA 0.25-4% FeCN','Cs/CA 0.375-4%FeCN','Cs/CA 0.5-4% FeCN','location','southeast','Orientation','horizontal','FontSize',12,'box','off','NumColumns',1);

title('Pore solution');
xlim([0 375]);
%ylim([0 350]);
%yticks([0:3:15])
set(gca,'FontSize',14);
exportgraphics(f3,'Pore solution_mg_g.pdf');
exportgraphics(f3,'Pore solution_mg_g.png');

%%
% f4=figure
% 
% plot(NCA.Time,C_NCA.*(NCA.Vol_ml/1000)./(NCA.mass_mg/1000),'ko-','LineWidth',1.3)
% hold on
% plot(NCs250.Time,C_NCs250.*(NCs250.Vol_ml/1000)./(NCs250.mass_mg/1000),'rs-','LineWidth',1.3)
% plot(NCs375.Time,C_NCs375.*(NCs375.Vol_ml/1000)./(NCs375.mass_mg/1000),'rd:','LineWidth',1.3)
% plot(NCs500.Time,C_NCs500.*(NCs500.Vol_ml/1000)./(NCs500.mass_mg/1000),'r^--','LineWidth',1.3)
% grid on
% xlabel('t [min]','Interpreter','tex');
% ylabel('FeCN/capsule [mg/g]')
% legend('CA','Cs/CA 0.25','Cs/CA 0.375','Cs/CA0.5','location','northeast','Orientation','horizontal','FontSize',14,'box','off','NumColumns',2);
% xlim([0 375]);
% ylim([0 350]);
% %yticks([0:3:15])
% set(gca,'FontSize',16);
% exportgraphics(f4,'Pore solution + NaCl_mg_g.pdf');
% exportgraphics(f4,'Pore solution + NaCl+mg_g.png');

%% As a percentage
%Max_dose=606/100*[100 50 59.51 57.13 99];  %Maxiumum in CA mulitpled by the capsulation efficiency from Cs bath
%Max_dose=[686 303 0.766*686 0.7081*686 0.9961*610];
Max_dose=[600 299.62 0.766*600 0.7081*600 0.99*600]; %4%
%Max_dose=[504.36 299.62 258.49 240.05 272.85]; %4%
f5=figure
plot(CA.Time,C_CA.*(CA.Vol_ml/1000)./(CA.mass_mg/1000)/Max_dose(1)*100,'ko-','LineWidth',1.3)
hold on
plot(CA.Time,C_CA_2p.*(CA_2p.Vol_ml/1000)./(CA_2p.mass_mg/1000)/Max_dose(2)*100,'bo-','LineWidth',1.3)

plot(Cs250.Time,C_Cs250.*(Cs250.Vol_ml/1000)./(Cs250.mass_mg/1000)/Max_dose(3)*100,'rs-','LineWidth',1.3)
plot(Cs375.Time,C_Cs375.*(Cs375.Vol_ml/1000)./(Cs375.mass_mg/1000)/Max_dose(4)*100,'rd:','LineWidth',1.3)
plot(Cs500.Time,C_Cs500.*(Cs500.Vol_ml/1000)./(Cs500.mass_mg/1000)/Max_dose(5)*100,'r^--','LineWidth',1.3)
grid on
xlabel('t [min]','Interpreter','tex');
ylabel('Release FeCN/FeCN_0 [%]')
legend('CA-4% FeCN','CA-2% FeCN','Cs/CA 0.25-4% FeCN','Cs/CA 0.375-4%FeCN','Cs/CA 0.5-4% FeCN','location','southeast','Orientation','horizontal','FontSize',12,'box','off','NumColumns',1);
title('Pore solution');
xlim([0 375]);
%ylim([0 100]);
%yticks([0:3:15])
set(gca,'FontSize',14);
exportgraphics(f5,'Pore solution_percentage.pdf');
exportgraphics(f5,'Pore solution_percentage.png');
%%
% f6=figure
% 
% plot(NCA.Time,C_NCA.*(NCA.Vol_ml/1000)./(NCA.mass_mg/1000)/Max_dose(1)*100,'ko-','LineWidth',1.3)
% hold on
% plot(NCs250.Time,C_NCs250.*(NCs250.Vol_ml/1000)./(NCs250.mass_mg/1000)/Max_dose(2)*100,'rs-','LineWidth',1.3)
% plot(NCs375.Time,C_NCs375.*(NCs375.Vol_ml/1000)./(NCs375.mass_mg/1000)/Max_dose(3)*100,'rd:','LineWidth',1.3)
% plot(NCs500.Time,C_NCs500.*(NCs500.Vol_ml/1000)./(NCs500.mass_mg/1000)/Max_dose(4)*100,'r^--','LineWidth',1.3)
% grid on
% xlabel('t [min]','Interpreter','tex');
% ylabel('FeCN released [%]')
% legend('CA','Cs/CA 0.25','Cs/CA 0.375','Cs/CA0.5','location','southeast','Orientation','horizontal','FontSize',14,'box','off','NumColumns',2);
% title('Pore solution + 5% NaCl');
% xlim([0 375]);
% ylim([0 100]);
% %yticks([0:3:15])
% set(gca,'FontSize',14);
% %exportgraphics(f6,'Pore solution+NaCl_percentage.pdf');
% exportgraphics(f6,'Pore solution+NaCl_percentage.png');
%% Combined graph

f7=figure

plot(CA.Time,C_CA.*(CA.Vol_ml/1000)./(CA.mass_mg/1000)/Max_dose(1)*100,'k^-','LineWidth',1.3)

hold on
plot(NCA.Time,C_NCA.*(NCA.Vol_ml/1000)./(NCA.mass_mg/1000)/Max_dose(1)*100,'k^--','LineWidth',1.3)

plot(Cs250.Time,C_Cs250.*(Cs250.Vol_ml/1000)./(Cs250.mass_mg/1000)/Max_dose(3)*100,'^-','LineWidth',1.3,'Color',[1 0.8 0.8])
plot(NCs250.Time,C_NCs250.*(NCs250.Vol_ml/1000)./(NCs250.mass_mg/1000)/Max_dose(3)*100,'^--','LineWidth',1.3,'Color',[0.8 0.8 1])

plot(Cs375.Time,C_Cs375.*(Cs375.Vol_ml/1000)./(Cs375.mass_mg/1000)/Max_dose(4)*100,'^-','LineWidth',1.3,'Color',[1 0.5 0.5])
plot(NCs375.Time,C_NCs375.*(NCs375.Vol_ml/1000)./(NCs375.mass_mg/1000)/Max_dose(4)*100,'^--','LineWidth',1.3,'Color',[0.5 0.5 1])

plot(Cs500.Time,C_Cs500.*(Cs500.Vol_ml/1000)./(Cs500.mass_mg/1000)/Max_dose(5)*100,'^-','LineWidth',1.3,'Color',[1 0 0])
plot(NCs500.Time,C_NCs500.*(NCs500.Vol_ml/1000)./(NCs500.mass_mg/1000)/Max_dose(5)*100,'^--','LineWidth',1.3,'Color',[0 0 1])

grid on

xlabel('t [min]','Interpreter','tex');
ylabel('FeCN released [%]')
legend('CA 4%','CA 2%', 'Cs/CA 0.25 4%','NCs/CA 0.25 2%','Cs/CA 0.375 4%','NCs/CA 0.375 2%','Cs/CA 0.5 4%','NCs/CA 0.5 2%','location','southeast','Orientation','horizontal','FontSize',12,'box','on','NumColumns',2);
%legend('CA', 'Cs/CA 0.25','Cs/CA 0.375','Cs/CA 0.5','location','southeast','Orientation','horizontal','FontSize',12,'box','on','NumColumns',1);
xlim([0 375]);
ylim([0 100]);
%yticks([0:3:15])
set(gca,'FontSize',14);
%exportgraphics(f7,'Pore solution_combined.pdf');
%exportgraphics(f7,'Pore solution_combined_xx.png');

%%

f8=figure
plot(NCA.Time,C_NCA.*(NCA.Vol_ml/1000)./(NCA.mass_mg/1000),'bo--','LineWidth',1.3)
hold on
plot(NCs250.Time,C_NCs250.*(NCs250.Vol_ml/1000)./(NCs250.mass_mg/1000),'^-','LineWidth',1.3,'Color',[0.8 0.8 1])
plot(NCs375.Time,C_NCs375.*(NCs375.Vol_ml/1000)./(NCs375.mass_mg/1000),'^-','LineWidth',1.3,'Color',[0.5 0.5 1])
plot(NCs500.Time,C_NCs500.*(NCs500.Vol_ml/1000)./(NCs500.mass_mg/1000),'^-','LineWidth',1.3,'Color',[0 0 0.7])


plot(CA.Time,C_CA.*(CA.Vol_ml/1000)./(CA.mass_mg/1000),'ro--','LineWidth',1.3)
plot(Cs250.Time,C_Cs250.*(Cs250.Vol_ml/1000)./(Cs250.mass_mg/1000),'^-','LineWidth',1.3,'Color',[1 0.8 0.8])
plot(Cs375.Time,C_Cs375.*(Cs375.Vol_ml/1000)./(Cs375.mass_mg/1000),'^-','LineWidth',1.3,'Color',[1 0.5 0.5])
plot(Cs500.Time,C_Cs500.*(Cs500.Vol_ml/1000)./(Cs500.mass_mg/1000),'^-','LineWidth',1.3,'Color',[0.7 0 0])
hold off

grid on

xlabel('Time [min]','Interpreter','none');
ylabel('NaFeCN released [mg g^{-1}]')
legend('CA-F_2','Cs-CA 0.25-F_2','Cs-CA 0.375-F_2','Cs-CA 0.5-F_2','CA-F_4','Cs-CA0.25-F_4','Cs-CA 0.375-F_4','Cs-CA 0.5-F_4','location','best','Orientation','vertical','FontSize',11,'box','on','NumColumns',2,'Interpreter','none','Position',[0.309446440279483 0.615846562951646 0.574999988291945 0.194047613654818]);
%legend('CA-F_4','CA-F_2', 'CsCA0.25-F_4','CsCA 0.25-F_2','CsCA 0.375-F_4','CsCA 0.375-F_2','CsCA 0.5-F_4','CsCA 0.5-F_2','location','eastoutside','Orientation','vertical','FontSize',12,'box','off','NumColumns',1,'Interpreter','none');
%legend('CA', 'Cs/CA 0.25','Cs/CA 0.375','Cs/CA 0.5','location','southeast','Orientation','horizontal','FontSize',12,'box','on','NumColumns',1);
xlim([0 375]);

%ylim([0 100]);
%yticks([0:3:15])
set(gca,'FontSize',14);
set(gca,'Units','normalized','OuterPosition',[0 0 1 1]);
exportgraphics(f8,'Pore solution_combined_adjusted_R2.pdf');
exportgraphics(f8,'Pore solution_combined_mgg_adjusted_R2.tif','resolution',300);

